# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ...core.datetime_utils import serialize_datetime
from ...core.pydantic_utilities import deep_union_pydantic_dicts, pydantic_v1


class ListMetricCountsParams(pydantic_v1.BaseModel):
    """
    Input parameters
    """

    company_id: typing.Optional[str] = None
    company_ids: typing.Optional[typing.List[str]] = None
    end_time: typing.Optional[dt.datetime] = None
    event_subtype: typing.Optional[str] = None
    event_subtypes: typing.Optional[typing.List[str]] = None
    grouping: typing.Optional[str] = None
    limit: typing.Optional[int] = None
    offset: typing.Optional[int] = None
    start_time: typing.Optional[dt.datetime] = None
    user_id: typing.Optional[str] = None

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic_v1.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import typing

CreateOrUpdateConditionRequestBodyOperator = typing.Union[
    typing.Literal["eq", "ne", "gt", "gte", "lt", "lte"], typing.Any
]



# This file was auto-generated by Fern from our API Definition.

from .types import (
    CountApiKeysParams,
    CountApiKeysResponse,
    CountApiRequestsParams,
    CountApiRequestsResponse,
    CreateApiKeyResponse,
    CreateEnvironmentRequestBodyEnvironmentType,
    CreateEnvironmentResponse,
    DeleteApiKeyResponse,
    DeleteEnvironmentResponse,
    GetApiKeyResponse,
    GetApiRequestResponse,
    GetEnvironmentResponse,
    ListApiKeysParams,
    ListApiKeysResponse,
    ListApiRequestsParams,
    ListApiRequestsResponse,
    ListEnvironmentsParams,
    ListEnvironmentsResponse,
    UpdateApiKeyResponse,
    UpdateEnvironmentRequestBodyEnvironmentType,
    UpdateEnvironmentResponse,
)

__all__ = [
    "CountApiKeysParams",
    "CountApiKeysResponse",
    "CountApiRequestsParams",
    "CountApiRequestsResponse",
    "CreateApiKeyResponse",
    "CreateEnvironmentRequestBodyEnvironmentType",
    "CreateEnvironmentResponse",
    "DeleteApiKeyResponse",
    "DeleteEnvironmentResponse",
    "GetApiKeyResponse",
    "GetApiRequestResponse",
    "GetEnvironmentResponse",
    "ListApiKeysParams",
    "ListApiKeysResponse",
    "ListApiRequestsParams",
    "ListApiRequestsResponse",
    "ListEnvironmentsParams",
    "ListEnvironmentsResponse",
    "UpdateApiKeyResponse",
    "UpdateEnvironmentRequestBodyEnvironmentType",
    "UpdateEnvironmentResponse",
]



# This file was auto-generated by Fern from our API Definition.

from .types import (
    CountCompaniesParams,
    CountCompaniesResponse,
    CountEntityKeyDefinitionsParams,
    CountEntityKeyDefinitionsResponse,
    CountEntityTraitDefinitionsParams,
    CountEntityTraitDefinitionsResponse,
    CountUsersParams,
    CountUsersResponse,
    CreateCompanyResponse,
    CreateEntityTraitDefinitionRequestBodyEntityType,
    CreateEntityTraitDefinitionRequestBodyTraitType,
    CreateUserResponse,
    DeleteCompanyByKeysResponse,
    DeleteCompanyMembershipResponse,
    DeleteCompanyResponse,
    DeleteUserByKeysResponse,
    DeleteUserResponse,
    GetActiveCompanySubscriptionParams,
    GetActiveCompanySubscriptionResponse,
    GetActiveDealsParams,
    GetActiveDealsResponse,
    GetCompanyResponse,
    GetEntityTraitDefinitionResponse,
    GetEntityTraitValuesParams,
    GetEntityTraitValuesResponse,
    GetOrCreateCompanyMembershipResponse,
    GetOrCreateEntityTraitDefinitionResponse,
    GetUserResponse,
    ListCompaniesParams,
    ListCompaniesResponse,
    ListCompanyMembershipsParams,
    ListCompanyMembershipsResponse,
    ListCompanyPlansParams,
    ListCompanyPlansResponse,
    ListEntityKeyDefinitionsParams,
    ListEntityKeyDefinitionsResponse,
    ListEntityTraitDefinitionsParams,
    ListEntityTraitDefinitionsResponse,
    ListUsersParams,
    ListUsersResponse,
    LookupCompanyParams,
    LookupCompanyResponse,
    LookupUserParams,
    LookupUserResponse,
    UpdateEntityTraitDefinitionRequestBodyTraitType,
    UpdateEntityTraitDefinitionResponse,
    UpsertCompanyResponse,
    UpsertCompanyTraitResponse,
    UpsertUserResponse,
    UpsertUserTraitResponse,
)

__all__ = [
    "CountCompaniesParams",
    "CountCompaniesResponse",
    "CountEntityKeyDefinitionsParams",
    "CountEntityKeyDefinitionsResponse",
    "CountEntityTraitDefinitionsParams",
    "CountEntityTraitDefinitionsResponse",
    "CountUsersParams",
    "CountUsersResponse",
    "CreateCompanyResponse",
    "CreateEntityTraitDefinitionRequestBodyEntityType",
    "CreateEntityTraitDefinitionRequestBodyTraitType",
    "CreateUserResponse",
    "DeleteCompanyByKeysResponse",
    "DeleteCompanyMembershipResponse",
    "DeleteCompanyResponse",
    "DeleteUserByKeysResponse",
    "DeleteUserResponse",
    "GetActiveCompanySubscriptionParams",
    "GetActiveCompanySubscriptionResponse",
    "GetActiveDealsParams",
    "GetActiveDealsResponse",
    "GetCompanyResponse",
    "GetEntityTraitDefinitionResponse",
    "GetEntityTraitValuesParams",
    "GetEntityTraitValuesResponse",
    "GetOrCreateCompanyMembershipResponse",
    "GetOrCreateEntityTraitDefinitionResponse",
    "GetUserResponse",
    "ListCompaniesParams",
    "ListCompaniesResponse",
    "ListCompanyMembershipsParams",
    "ListCompanyMembershipsResponse",
    "ListCompanyPlansParams",
    "ListCompanyPlansResponse",
    "ListEntityKeyDefinitionsParams",
    "ListEntityKeyDefinitionsResponse",
    "ListEntityTraitDefinitionsParams",
    "ListEntityTraitDefinitionsResponse",
    "ListUsersParams",
    "ListUsersResponse",
    "LookupCompanyParams",
    "LookupCompanyResponse",
    "LookupUserParams",
    "LookupUserResponse",
    "UpdateEntityTraitDefinitionRequestBodyTraitType",
    "UpdateEntityTraitDefinitionResponse",
    "UpsertCompanyResponse",
    "UpsertCompanyTraitResponse",
    "UpsertUserResponse",
    "UpsertUserTraitResponse",
]



# This file was auto-generated by Fern from our API Definition.

from .types import (
    ListCrmProductsParams,
    ListCrmProductsResponse,
    UpsertCrmDealResponse,
    UpsertCrmProductResponse,
    UpsertDealLineItemAssociationResponse,
    UpsertLineItemResponse,
)

__all__ = [
    "ListCrmProductsParams",
    "ListCrmProductsResponse",
    "UpsertCrmDealResponse",
    "UpsertCrmProductResponse",
    "UpsertDealLineItemAssociationResponse",
    "UpsertLineItemResponse",
]



# This file was auto-generated by Fern from our API Definition.

from .types import (
    ListProductsParams,
    ListProductsResponse,
    UpsertBillingProductResponse,
    UpsertBillingSubscriptionResponse,
)

__all__ = [
    "ListProductsParams",
    "ListProductsResponse",
    "UpsertBillingProductResponse",
    "UpsertBillingSubscriptionResponse",
]



# This file was auto-generated by Fern from our API Definition.

import typing

from .event_body_identify import EventBodyIdentify
from .event_body_track import EventBodyTrack

EventBody = typing.Union[EventBodyTrack, EventBodyIdentify]
